is_block_directive_with_extras

Function is_block_directive_with_extras 

pub fn is_block_directive_with_extras(name: &str, additional: &[String]) -> bool
Check if a directive is a block directive, including custom additions

This function checks the built-in list plus any additional block directives specified in the configuration.

Examples

use nginx_lint_parser::is_block_directive_with_extras;

assert!(is_block_directive_with_extras("server", &[]));
assert!(is_block_directive_with_extras("my_custom_block", &["my_custom_block".to_string()]));
assert!(!is_block_directive_with_extras("listen", &[]));