pub fn parse_string(source: &str) -> ParseResult<Config>Expand description
Parse nginx configuration from a string
Uses the rowan-based lossless CST parser internally and converts to AST. Returns an error if the source contains syntax errors.
pub fn parse_string(source: &str) -> ParseResult<Config>Parse nginx configuration from a string
Uses the rowan-based lossless CST parser internally and converts to AST. Returns an error if the source contains syntax errors.