parse

Function parse 

pub fn parse(tokens: Vec<(SyntaxKind, &str)>) -> (GreenNode, Vec<SyntaxError>)
Parse a flat token list into a rowan green tree.

Returns the root green node and any errors encountered during parsing.