Module syntax_kind

Module syntax_kind 

Syntax kind definitions for the rowan-based nginx config parser.

Each variant of SyntaxKind represents either a leaf token or an interior node in the lossless concrete syntax tree.

Enums

NginxLanguage
The language tag used by rowan to parameterise the syntax tree.
SyntaxKind
All token and node kinds used by the nginx configuration parser.

Type Aliases

SyntaxElement
Either a node or a token.
SyntaxNode
A node in the nginx configuration syntax tree.
SyntaxToken
A token (leaf) in the nginx configuration syntax tree.