Syntax kind definitions for the rowan-based nginx config parser.
Each variant of SyntaxKind represents either a leaf token or an interior
node in the lossless concrete syntax tree.
Enums
- Nginx
Language - The language tag used by rowan to parameterise the syntax tree.
- Syntax
Kind - All token and node kinds used by the nginx configuration parser.
Type Aliases
- Syntax
Element - Either a node or a token.
- Syntax
Node - A node in the nginx configuration syntax tree.
- Syntax
Token - A token (leaf) in the nginx configuration syntax tree.